==> jc-1.4.0.tar.gz: java/nio/charset/CoderMalfunctionError.h <==
// public class java.nio.charset.CoderMalfunctionError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6293402740375f94 java_nio_charset_CoderMalfunctionError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_nio_charset_CoderMalfunctionError_H_
#define _JC_java_nio_charset_CoderMalfunctionError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderMalfunctionError$sub_refs	_jc_java_nio_charset_CoderMalfunctionError$sub_refs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs	_jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$refs	_jc_java_nio_charset_CoderMalfunctionError$refs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$nonrefs	_jc_java_nio_charset_CoderMalfunctionError$nonrefs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$object	_jc_java_nio_charset_CoderMalfunctionError$object;

typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vmethods	_jc_java_nio_charset_CoderMalfunctionError$vmethods;
typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vtable	_jc_java_nio_charset_CoderMalfunctionError$vtable;
typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vtype	_jc_java_nio_charset_CoderMalfunctionError$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderMalfunctionError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_java_nio_charset_CoderMalfunctionError$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_java_nio_charset_CoderMalfunctionError$vmethods {
};

// Vtable
struct _jc_java_nio_charset_CoderMalfunctionError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_nio_charset_CoderMalfunctionError$vmethods	java_nio_charset_CoderMalfunctionError;
};

// Vtype
struct _jc_java_nio_charset_CoderMalfunctionError$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderMalfunctionError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderMalfunctionError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderMalfunctionError$refs {
    _jc_java_nio_charset_CoderMalfunctionError$sub_refs	java_nio_charset_CoderMalfunctionError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderMalfunctionError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs	java_nio_charset_CoderMalfunctionError;
};

// Object instance structure
struct _jc_java_nio_charset_CoderMalfunctionError$object {
	_jc_java_nio_charset_CoderMalfunctionError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderMalfunctionError$vtype	*vtype;
	_jc_java_nio_charset_CoderMalfunctionError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderMalfunctionError$vtype _jc_java_nio_charset_CoderMalfunctionError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderMalfunctionError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderMalfunctionError$class_object;

#endif	/* _JC_java_nio_charset_CoderMalfunctionError_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CoderMalfunctionError.h <==
// public class java.nio.charset.CoderMalfunctionError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 6293402740375f94 java_nio_charset_CoderMalfunctionError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_nio_charset_CoderMalfunctionError_H_
#define _JC_java_nio_charset_CoderMalfunctionError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderMalfunctionError$sub_refs	_jc_java_nio_charset_CoderMalfunctionError$sub_refs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs	_jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$refs	_jc_java_nio_charset_CoderMalfunctionError$refs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$nonrefs	_jc_java_nio_charset_CoderMalfunctionError$nonrefs;
typedef struct _jc_java_nio_charset_CoderMalfunctionError$object	_jc_java_nio_charset_CoderMalfunctionError$object;

typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vmethods	_jc_java_nio_charset_CoderMalfunctionError$vmethods;
typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vtable	_jc_java_nio_charset_CoderMalfunctionError$vtable;
typedef const struct _jc_java_nio_charset_CoderMalfunctionError$vtype	_jc_java_nio_charset_CoderMalfunctionError$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderMalfunctionError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_java_nio_charset_CoderMalfunctionError$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_charset_CoderMalfunctionError$vmethods {
};

// Vtable
struct _jc_java_nio_charset_CoderMalfunctionError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_nio_charset_CoderMalfunctionError$vmethods	java_nio_charset_CoderMalfunctionError;
};

// Vtype
struct _jc_java_nio_charset_CoderMalfunctionError$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderMalfunctionError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderMalfunctionError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderMalfunctionError$refs {
    _jc_java_nio_charset_CoderMalfunctionError$sub_refs	java_nio_charset_CoderMalfunctionError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderMalfunctionError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_nio_charset_CoderMalfunctionError$sub_nonrefs	java_nio_charset_CoderMalfunctionError;
};

// Object instance structure
struct _jc_java_nio_charset_CoderMalfunctionError$object {
	_jc_java_nio_charset_CoderMalfunctionError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderMalfunctionError$vtype	*vtype;
	_jc_java_nio_charset_CoderMalfunctionError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderMalfunctionError$vtype _jc_java_nio_charset_CoderMalfunctionError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderMalfunctionError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderMalfunctionError$class_object;

#endif	/* _JC_java_nio_charset_CoderMalfunctionError_H_ */
